key property
The full key, present only in the create response.
Implementation
String get id; String? get name; String? get start; String? get prefix;/// The full key, present only in the create response.
String? get key;
The full key, present only in the create response.
String get id; String? get name; String? get start; String? get prefix;/// The full key, present only in the create response.
String? get key;