toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final _this = this as ApiKey;
  return 'ApiKey(id: ${_this.id}, name: ${_this.name}, start: ${_this.start}, prefix: ${_this.prefix}, key: ${_this.key}, userId: ${_this.userId}, enabled: ${_this.enabled}, remaining: ${_this.remaining}, refillAmount: ${_this.refillAmount}, refillInterval: ${_this.refillInterval}, rateLimitEnabled: ${_this.rateLimitEnabled}, rateLimitMax: ${_this.rateLimitMax}, rateLimitTimeWindow: ${_this.rateLimitTimeWindow}, requestCount: ${_this.requestCount}, lastRequest: ${_this.lastRequest}, expiresAt: ${_this.expiresAt}, createdAt: ${_this.createdAt}, updatedAt: ${_this.updatedAt}, metadata: ${_this.metadata})';
}