BetterAuthApiKey class abstract

Typed wrapper for the Better Auth apiKey() plugin routes.

Annotations
  • @RestApi.new(callAdapter: BetterAuthCallAdapter)

Constructors

BetterAuthApiKey(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required CreateApiKeyBody body}) Future<Result<ApiKey>>
Creates a key. The returned ApiKey.key is the only time the full secret is exposed.
delete({required Map<String, dynamic> body}) Future<Result<StatusResponse>>
Deletes a key.
get({required String id}) Future<Result<ApiKey>>
Fetches one key by id.
list() Future<Result<List<ApiKey>>>
Lists the current user's keys.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update({required UpdateApiKeyBody body}) Future<Result<ApiKey>>
Updates a key.

Operators

operator ==(Object other) bool
The equality operator.
inherited