CreateApiKeyBody class abstract

Body for creating an API key.

Available extensions
Annotations
  • @freezed

Constructors

CreateApiKeyBody({String? name, String? prefix, int? expiresIn, int? remaining, int? refillAmount, int? refillInterval, int? rateLimitMax, int? rateLimitTimeWindow, bool? rateLimitEnabled, Map<String, dynamic>? metadata})
const
factory
CreateApiKeyBody.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $CreateApiKeyBodyCopyWith<CreateApiKeyBody>
Create a copy of CreateApiKeyBody with the given fields replaced by the non-null parameter values.
no setterinherited
expiresIn int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
no setterinherited
name String?
no setterinherited
prefix String?
no setterinherited
rateLimitEnabled bool?
no setterinherited
rateLimitMax int?
no setterinherited
rateLimitTimeWindow int?
no setterinherited
refillAmount int?
no setterinherited
refillInterval int?
no setterinherited
remaining int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CreateApiKeyBody value)) → TResult

Available on CreateApiKeyBody, provided by the CreateApiKeyBodyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CreateApiKeyBody value)?) → TResult?

Available on CreateApiKeyBody, provided by the CreateApiKeyBodyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CreateApiKeyBody value)?, {required TResult orElse()}) → TResult

Available on CreateApiKeyBody, provided by the CreateApiKeyBodyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? name, String? prefix, int? expiresIn, int? remaining, int? refillAmount, int? refillInterval, int? rateLimitMax, int? rateLimitTimeWindow, bool? rateLimitEnabled, Map<String, dynamic>? metadata)?, {required TResult orElse()}) → TResult

Available on CreateApiKeyBody, provided by the CreateApiKeyBodyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CreateApiKeyBody to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? name, String? prefix, int? expiresIn, int? remaining, int? refillAmount, int? refillInterval, int? rateLimitMax, int? rateLimitTimeWindow, bool? rateLimitEnabled, Map<String, dynamic>? metadata)) → TResult

Available on CreateApiKeyBody, provided by the CreateApiKeyBodyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? name, String? prefix, int? expiresIn, int? remaining, int? refillAmount, int? refillInterval, int? rateLimitMax, int? rateLimitTimeWindow, bool? rateLimitEnabled, Map<String, dynamic>? metadata)?) → TResult?

Available on CreateApiKeyBody, provided by the CreateApiKeyBodyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited