toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final _this = this as CreateApiKeyBody;
  return 'CreateApiKeyBody(name: ${_this.name}, prefix: ${_this.prefix}, expiresIn: ${_this.expiresIn}, remaining: ${_this.remaining}, refillAmount: ${_this.refillAmount}, refillInterval: ${_this.refillInterval}, rateLimitMax: ${_this.rateLimitMax}, rateLimitTimeWindow: ${_this.rateLimitTimeWindow}, rateLimitEnabled: ${_this.rateLimitEnabled}, metadata: ${_this.metadata})';
}