UpdateApiKeyBody class abstract

Body for updating an API key.

Available extensions
Annotations
  • @freezed

Constructors

UpdateApiKeyBody({required String keyId, String? name, bool? enabled, int? remaining, Map<String, dynamic>? metadata})
const
factory
UpdateApiKeyBody.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UpdateApiKeyBodyCopyWith<UpdateApiKeyBody>
Create a copy of UpdateApiKeyBody with the given fields replaced by the non-null parameter values.
no setterinherited
enabled bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
keyId String
no setterinherited
metadata Map<String, dynamic>?
no setterinherited
name String?
no setterinherited
remaining int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_UpdateApiKeyBody value)) → TResult

Available on UpdateApiKeyBody, provided by the UpdateApiKeyBodyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_UpdateApiKeyBody value)?) → TResult?

Available on UpdateApiKeyBody, provided by the UpdateApiKeyBodyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_UpdateApiKeyBody value)?, {required TResult orElse()}) → TResult

Available on UpdateApiKeyBody, provided by the UpdateApiKeyBodyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String keyId, String? name, bool? enabled, int? remaining, Map<String, dynamic>? metadata)?, {required TResult orElse()}) → TResult

Available on UpdateApiKeyBody, provided by the UpdateApiKeyBodyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UpdateApiKeyBody to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String keyId, String? name, bool? enabled, int? remaining, Map<String, dynamic>? metadata)) → TResult

Available on UpdateApiKeyBody, provided by the UpdateApiKeyBodyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String keyId, String? name, bool? enabled, int? remaining, Map<String, dynamic>? metadata)?) → TResult?

Available on UpdateApiKeyBody, provided by the UpdateApiKeyBodyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited