BearerOptions class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- BearerOptions({@Default.new(false) bool requireSignature})
-
constfactory
-
BearerOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $BearerOptionsCopyWith<
BearerOptions> -
Create a copy of BearerOptions
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- requireSignature → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BearerOptions value)) → TResult -
Available on BearerOptions, provided by the BearerOptionsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BearerOptions value)?) → TResult? -
Available on BearerOptions, provided by the BearerOptionsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BearerOptions value)?, {required TResult orElse()}) → TResult -
Available on BearerOptions, provided by the BearerOptionsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool requireSignature)?, {required TResult orElse()}) → TResult -
Available on BearerOptions, provided by the BearerOptionsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BearerOptions to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool requireSignature)) → TResult -
Available on BearerOptions, provided by the BearerOptionsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool requireSignature)?) → TResult? -
Available on BearerOptions, provided by the BearerOptionsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited