plugins/jwt library

JWT plugin: mint a short-lived JWT for your own backend, and fetch the JWKS used to verify it.

Requires the jwt() plugin on your Better Auth server. Importing this library adds a jwt getter to BetterAuthClient.

Extensions

BetterAuthJwtExtension on BetterAuthClient
JwtKeyPatterns on JwtKey
Adds pattern-matching-related methods to JwtKey.
JwtKeyResponsePatterns on JwtKeyResponse
Adds pattern-matching-related methods to JwtKeyResponse.
JwtTokenResponsePatterns on JwtTokenResponse
Adds pattern-matching-related methods to JwtTokenResponse.