JwtKeyResponsePatterns extension

Adds pattern-matching-related methods to JwtKeyResponse.

on

Methods

map<TResult extends Object?>(TResult $default(_JwtKeyResponse value)) → TResult

Available on JwtKeyResponse, provided by the JwtKeyResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_JwtKeyResponse value)?) → TResult?

Available on JwtKeyResponse, provided by the JwtKeyResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_JwtKeyResponse value)?, {required TResult orElse()}) → TResult

Available on JwtKeyResponse, provided by the JwtKeyResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<JwtKey> keys)?, {required TResult orElse()}) → TResult

Available on JwtKeyResponse, provided by the JwtKeyResponsePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<JwtKey> keys)) → TResult

Available on JwtKeyResponse, provided by the JwtKeyResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<JwtKey> keys)?) → TResult?

Available on JwtKeyResponse, provided by the JwtKeyResponsePatterns extension

A variant of when that fallback to returning null