MagicLinkBody class abstract
Body for requesting a magic-link email.
- Available extensions
- Annotations
-
- @freezed
Constructors
- MagicLinkBody({required String email, String? name, String? callbackURL, String? newUserCallbackURL, String? errorCallbackURL})
-
constfactory
-
MagicLinkBody.fromJson(Map<
String, dynamic> json) -
factory
Properties
- callbackURL → String?
-
no setterinherited
-
copyWith
→ $MagicLinkBodyCopyWith<
MagicLinkBody> -
Create a copy of MagicLinkBody
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String
-
no setterinherited
- errorCallbackURL → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
no setterinherited
- newUserCallbackURL → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_MagicLinkBody value)) → TResult -
Available on MagicLinkBody, provided by the MagicLinkBodyPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_MagicLinkBody value)?) → TResult? -
Available on MagicLinkBody, provided by the MagicLinkBodyPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_MagicLinkBody value)?, {required TResult orElse()}) → TResult -
Available on MagicLinkBody, provided by the MagicLinkBodyPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String email, String? name, String? callbackURL, String? newUserCallbackURL, String? errorCallbackURL)?, {required TResult orElse()}) → TResult -
Available on MagicLinkBody, provided by the MagicLinkBodyPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this MagicLinkBody to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String email, String? name, String? callbackURL, String? newUserCallbackURL, String? errorCallbackURL)) → TResult -
Available on MagicLinkBody, provided by the MagicLinkBodyPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String email, String? name, String? callbackURL, String? newUserCallbackURL, String? errorCallbackURL)?) → TResult? -
Available on MagicLinkBody, provided by the MagicLinkBodyPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited