setActive abstract method
Switches the active account to the one with sessionToken.
Implementation
@POST("/multi-session/set-active")
Future<Result<SignInEmailResponse>> setActive({
@Body() required Map<String, dynamic> body,
});
Switches the active account to the one with sessionToken.
@POST("/multi-session/set-active")
Future<Result<SignInEmailResponse>> setActive({
@Body() required Map<String, dynamic> body,
});