Invitation class abstract

An invitation to join an organization.

Available extensions
Annotations
  • @freezed

Constructors

Invitation({required String id, required String organizationId, required String email, required String role, required String status, String? inviterId, DateTime? expiresAt})
const
factory
Invitation.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $InvitationCopyWith<Invitation>
Create a copy of Invitation with the given fields replaced by the non-null parameter values.
no setterinherited
email String
no setterinherited
expiresAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
inviterId String?
no setterinherited
organizationId String
no setterinherited
role String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
One of pending, accepted, rejected, canceled.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Invitation value)) → TResult

Available on Invitation, provided by the InvitationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Invitation value)?) → TResult?

Available on Invitation, provided by the InvitationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Invitation value)?, {required TResult orElse()}) → TResult

Available on Invitation, provided by the InvitationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String organizationId, String email, String role, String status, String? inviterId, DateTime? expiresAt)?, {required TResult orElse()}) → TResult

Available on Invitation, provided by the InvitationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Invitation to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String organizationId, String email, String role, String status, String? inviterId, DateTime? expiresAt)) → TResult

Available on Invitation, provided by the InvitationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String organizationId, String email, String role, String status, String? inviterId, DateTime? expiresAt)?) → TResult?

Available on Invitation, provided by the InvitationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited