Member class abstract

A member of an organization.

Available extensions
Annotations
  • @freezed

Constructors

Member({required String id, required String userId, required String organizationId, required String role, String? name, String? email, String? image, DateTime? createdAt})
const
factory
Member.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $MemberCopyWith<Member>
Create a copy of Member with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime?
no setterinherited
email String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
image String?
no setterinherited
name String?
no setterinherited
organizationId String
no setterinherited
role String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Member value)) → TResult

Available on Member, provided by the MemberPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Member value)?) → TResult?

Available on Member, provided by the MemberPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Member value)?, {required TResult orElse()}) → TResult

Available on Member, provided by the MemberPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String userId, String organizationId, String role, String? name, String? email, String? image, DateTime? createdAt)?, {required TResult orElse()}) → TResult

Available on Member, provided by the MemberPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Member to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String userId, String organizationId, String role, String? name, String? email, String? image, DateTime? createdAt)) → TResult

Available on Member, provided by the MemberPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String userId, String organizationId, String role, String? name, String? email, String? image, DateTime? createdAt)?) → TResult?

Available on Member, provided by the MemberPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited