toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final _this = this as Member;
  return 'Member(id: ${_this.id}, userId: ${_this.userId}, organizationId: ${_this.organizationId}, role: ${_this.role}, name: ${_this.name}, email: ${_this.email}, image: ${_this.image}, createdAt: ${_this.createdAt})';
}