PasskeyRecord class abstract

Stored passkey row from Better Auth passkey.

Available extensions
Annotations
  • @freezed

Constructors

PasskeyRecord({required String id, String? name, required String userId, required String credentialID, required String publicKey, @JsonKey.new(fromJson: _counterFromJson) required int counter, required String deviceType, required bool backedUp, String? transports, DateTime? createdAt, DateTime? updatedAt, String? aaguid})
const
factory
PasskeyRecord.fromJson(Map<String, dynamic> json)
factory

Properties

aaguid String?
no setterinherited
backedUp bool
no setterinherited
copyWith → $PasskeyRecordCopyWith<PasskeyRecord>
Create a copy of PasskeyRecord with the given fields replaced by the non-null parameter values.
no setterinherited
counter int
no setterinherited
createdAt DateTime?
no setterinherited
credentialID String
no setterinherited
deviceType String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
name String?
no setterinherited
publicKey String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transports String?
no setterinherited
updatedAt DateTime?
no setterinherited
userId String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PasskeyRecord value)) → TResult

Available on PasskeyRecord, provided by the PasskeyRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PasskeyRecord value)?) → TResult?

Available on PasskeyRecord, provided by the PasskeyRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PasskeyRecord value)?, {required TResult orElse()}) → TResult

Available on PasskeyRecord, provided by the PasskeyRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String? name, String userId, String credentialID, String publicKey, int counter, String deviceType, bool backedUp, String? transports, DateTime? createdAt, DateTime? updatedAt, String? aaguid)?, {required TResult orElse()}) → TResult

Available on PasskeyRecord, provided by the PasskeyRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PasskeyRecord to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String? name, String userId, String credentialID, String publicKey, int counter, String deviceType, bool backedUp, String? transports, DateTime? createdAt, DateTime? updatedAt, String? aaguid)) → TResult

Available on PasskeyRecord, provided by the PasskeyRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String? name, String userId, String credentialID, String publicKey, int counter, String deviceType, bool backedUp, String? transports, DateTime? createdAt, DateTime? updatedAt, String? aaguid)?) → TResult?

Available on PasskeyRecord, provided by the PasskeyRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited