VerifyPhoneBodyPatterns extension

Adds pattern-matching-related methods to VerifyPhoneBody.

on

Methods

map<TResult extends Object?>(TResult $default(_VerifyPhoneBody value)) → TResult

Available on VerifyPhoneBody, provided by the VerifyPhoneBodyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VerifyPhoneBody value)?) → TResult?

Available on VerifyPhoneBody, provided by the VerifyPhoneBodyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VerifyPhoneBody value)?, {required TResult orElse()}) → TResult

Available on VerifyPhoneBody, provided by the VerifyPhoneBodyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String phoneNumber, String code, String? disableSession, String? updatePhoneNumber)?, {required TResult orElse()}) → TResult

Available on VerifyPhoneBody, provided by the VerifyPhoneBodyPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String phoneNumber, String code, String? disableSession, String? updatePhoneNumber)) → TResult

Available on VerifyPhoneBody, provided by the VerifyPhoneBodyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String phoneNumber, String code, String? disableSession, String? updatePhoneNumber)?) → TResult?

Available on VerifyPhoneBody, provided by the VerifyPhoneBodyPatterns extension

A variant of when that fallback to returning null