TwoFactorEnableBody class abstract

Body for enabling two-factor auth. password re-authenticates the user.

Available extensions
Annotations
  • @freezed

Constructors

TwoFactorEnableBody({required String password, String? issuer})
const
factory
TwoFactorEnableBody.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $TwoFactorEnableBodyCopyWith<TwoFactorEnableBody>
Create a copy of TwoFactorEnableBody with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
issuer String?
no setterinherited
password String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TwoFactorEnableBody value)) → TResult

Available on TwoFactorEnableBody, provided by the TwoFactorEnableBodyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TwoFactorEnableBody value)?) → TResult?

Available on TwoFactorEnableBody, provided by the TwoFactorEnableBodyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TwoFactorEnableBody value)?, {required TResult orElse()}) → TResult

Available on TwoFactorEnableBody, provided by the TwoFactorEnableBodyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String password, String? issuer)?, {required TResult orElse()}) → TResult

Available on TwoFactorEnableBody, provided by the TwoFactorEnableBodyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TwoFactorEnableBody to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String password, String? issuer)) → TResult

Available on TwoFactorEnableBody, provided by the TwoFactorEnableBodyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String password, String? issuer)?) → TResult?

Available on TwoFactorEnableBody, provided by the TwoFactorEnableBodyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited