TwoFactorEnableResponse class abstract

Response from enabling 2FA: the TOTP URI to render as a QR code, plus one-time backup codes to show the user once.

Available extensions
Annotations
  • @freezed

Constructors

TwoFactorEnableResponse({required String totpURI, @Default.new(<String>[]) List<String> backupCodes})
const
factory
TwoFactorEnableResponse.fromJson(Map<String, dynamic> json)
factory

Properties

backupCodes List<String>
no setterinherited
copyWith → $TwoFactorEnableResponseCopyWith<TwoFactorEnableResponse>
Create a copy of TwoFactorEnableResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totpURI String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TwoFactorEnableResponse value)) → TResult

Available on TwoFactorEnableResponse, provided by the TwoFactorEnableResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TwoFactorEnableResponse value)?) → TResult?

Available on TwoFactorEnableResponse, provided by the TwoFactorEnableResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TwoFactorEnableResponse value)?, {required TResult orElse()}) → TResult

Available on TwoFactorEnableResponse, provided by the TwoFactorEnableResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String totpURI, List<String> backupCodes)?, {required TResult orElse()}) → TResult

Available on TwoFactorEnableResponse, provided by the TwoFactorEnableResponsePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TwoFactorEnableResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String totpURI, List<String> backupCodes)) → TResult

Available on TwoFactorEnableResponse, provided by the TwoFactorEnableResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String totpURI, List<String> backupCodes)?) → TResult?

Available on TwoFactorEnableResponse, provided by the TwoFactorEnableResponsePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited