TwoFactorPasswordBody class abstract

Body for routes that only need the user's password (disable, get TOTP URI).

Available extensions
Annotations
  • @freezed

Constructors

TwoFactorPasswordBody({required String password})
const
factory
TwoFactorPasswordBody.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $TwoFactorPasswordBodyCopyWith<TwoFactorPasswordBody>
Create a copy of TwoFactorPasswordBody with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
password String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TwoFactorPasswordBody value)) → TResult

Available on TwoFactorPasswordBody, provided by the TwoFactorPasswordBodyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TwoFactorPasswordBody value)?) → TResult?

Available on TwoFactorPasswordBody, provided by the TwoFactorPasswordBodyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TwoFactorPasswordBody value)?, {required TResult orElse()}) → TResult

Available on TwoFactorPasswordBody, provided by the TwoFactorPasswordBodyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String password)?, {required TResult orElse()}) → TResult

Available on TwoFactorPasswordBody, provided by the TwoFactorPasswordBodyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TwoFactorPasswordBody to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String password)) → TResult

Available on TwoFactorPasswordBody, provided by the TwoFactorPasswordBodyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String password)?) → TResult?

Available on TwoFactorPasswordBody, provided by the TwoFactorPasswordBodyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited