BetterAuthAnonymous class abstract
Typed wrapper for the Better Auth anonymous() plugin.
These routes do not exist in the core client — the anonymous plugin is new HTTP surface, not a re-typing of existing routes.
- Annotations
-
- @RestApi.new(callAdapter: BetterAuthCallAdapter)
Constructors
- BetterAuthAnonymous(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signIn(
) → Future< Result< SignInEmailResponse> > -
Creates a guest session. The returned user has
isAnonymous == true. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited