BetterAuthOneTimeToken class abstract
Typed wrapper for the Better Auth oneTimeToken() plugin.
Generates a short-lived token bound to the current session, which another context can exchange for that session. New HTTP surface.
- Annotations
-
- @RestApi.new(callAdapter: BetterAuthCallAdapter)
Constructors
- BetterAuthOneTimeToken(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
) → Future< Result< OneTimeTokenResponse> > - Generates a one-time token for the current session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
{required Map< String, dynamic> body}) → Future<Result< SessionResponse> > - Exchanges a token for its session.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited