BetterAuthOrganization class abstract
Typed wrapper for the most-used Better Auth organization() routes.
The remaining routes (check-slug, has-permission, cancel/reject invitation, …) are reachable untyped via the core client while this surface grows.
- Annotations
-
- @RestApi.new(callAdapter: BetterAuthCallAdapter)
Constructors
- BetterAuthOrganization(Dio dio, {String? baseUrl, ParseErrorLogger? errorLogger})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptInvitation(
{required Map< String, dynamic> body}) → Future<Result< Invitation> > -
create(
{required CreateOrganizationBody body}) → Future< Result< Organization> > -
getFullOrganization(
{String? organizationId}) → Future< Result< FullOrganization> > -
inviteMember(
{required InviteMemberBody body}) → Future< Result< Invitation> > -
list(
) → Future< Result< List< >Organization> > -
listInvitations(
{String? organizationId}) → Future< Result< List< >Invitation> > -
listMembers(
{String? organizationId}) → Future< Result< List< >Member> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeMember(
{required Map< String, dynamic> body}) → Future<Result< StatusResponse> > -
setActive(
{required Map< String, dynamic> body}) → Future<Result< FullOrganization> > - Sets the active organization for the session. Pass a null id to clear it.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateMemberRole(
{required Map< String, dynamic> body}) → Future<Result< Member> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited